==> qiho-center-api-2.11.4-sources.jar: com/qiho/center/api/dto/page/BaiqiPageDto.java <==
package com.qiho.center.api.dto.page;

import com.qiho.center.api.dto.BaseDto;
import com.qiho.center.api.enums.page.PageStatusEnum;
import com.qiho.center.api.enums.page.PageTypeEnum;

import java.util.Date;
import java.util.List;

/**
 * @author peanut.huang
 * @date 2018/2/23.
 */
public class BaiqiPageDto extends BaseDto {

    private static final long serialVersionUID = 3531839515998545089L;

    /**
     * 页面id
     */
    private Long id;

    /**
     * 页面名称
     */
    private String pageName;

    /**
     * 页面类型 {@link PageTypeEnum#value}
     */
    private Integer pageType;

    /**
     * 页面地址
     */
    private String pageUrl;

    /**
     * 页面效果图地址
     */
    private String pageImg;

    /**
     * 页面状态 {@link PageStatusEnum#value}
     */
    private Integer pageStatus;

    /**
     * 页面md5
     */
    private String pageMd5;

    /**
     * 页面其他信息
     */
    private String pageInfo;

    /**
     * 页面最后操作人
     */
    private String operatorName;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /**
     * 落地页链接 eg:https://m.7hotest.com/item/detail2?id=832&pid=168
     */
    private String landPageUrl;

    /**
     * 创建人
     */
    private String createName;

    /**
     * 页面原生类型
     */
    private Integer originType;

    /**
     * 标签
     */
    private String tagNums;

    /**
     * 页面表单策略
     */
    private List<PageFormStrategyDto> strategyTypeList;

    /**
     * 自动打标
     */
    private String autoPromoteTag;

    /**
     * 是否是保存落地页
     */
    private Boolean landPageSaveFlag;

    /**
     * 媒体备案信息自定义
     */
    private String landpageMedia;

    public String getLandpageMedia() {
        return landpageMedia;
    }

    public void setLandpageMedia(String landpageMedia) {
        this.landpageMedia = landpageMedia;
    }

    public Boolean getLandPageSaveFlag() {
        return landPageSaveFlag;
    }

    public void setLandPageSaveFlag(Boolean landPageSaveFlag) {
        this.landPageSaveFlag = landPageSaveFlag;
    }

    public String getAutoPromoteTag() {
        return autoPromoteTag;
    }

    public void setAutoPromoteTag(String autoPromoteTag) {
        this.autoPromoteTag = autoPromoteTag;
    }

    public String getTagNums() {
        return tagNums;
    }

    public void setTagNums(String tagNums) {
        this.tagNums = tagNums;
    }
    /**
     * 代码配置 目前只有通过代码添加模版的场景下才会传值
     */
    private String codeConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPageName() {
        return pageName;
    }

    public void setPageName(String pageName) {
        this.pageName = pageName;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public Integer getPageStatus() {
        return pageStatus;
    }

    public void setPageStatus(Integer pageStatus) {
        this.pageStatus = pageStatus;
    }

    public String getPageMd5() {
        return pageMd5;
    }

    public void setPageMd5(String pageMd5) {
        this.pageMd5 = pageMd5;
    }

    public String getPageInfo() {
        return pageInfo;
    }

    public void setPageInfo(String pageInfo) {
        this.pageInfo = pageInfo;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getPageImg() {
        return pageImg;
    }

    public void setPageImg(String pageImg) {
        this.pageImg = pageImg;
    }

    public String getLandPageUrl() {
        return landPageUrl;
    }

    public void setLandPageUrl(String landPageUrl) {
        this.landPageUrl = landPageUrl;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<PageFormStrategyDto> getStrategyTypeList() {
        return strategyTypeList;
    }

    public void setStrategyTypeList(List<PageFormStrategyDto> strategyTypeList) {
        this.strategyTypeList = strategyTypeList;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }

    public String getCodeConfig() {
        return codeConfig;
    }

    public void setCodeConfig(String codeConfig) {
        this.codeConfig = codeConfig;
    }
}

==> qiho-center-api-2.11.7-20211104.030331-1-sources.jar: com/qiho/center/api/dto/page/BaiqiPageDto.java <==
package com.qiho.center.api.dto.page;

import com.qiho.center.api.dto.BaseDto;
import com.qiho.center.api.enums.page.PageStatusEnum;
import com.qiho.center.api.enums.page.PageTypeEnum;

import java.util.Date;
import java.util.List;

/**
 * @author peanut.huang
 * @date 2018/2/23.
 */
public class BaiqiPageDto extends BaseDto {

    private static final long serialVersionUID = 3531839515998545089L;

    /**
     * 页面id
     */
    private Long id;

    /**
     * 页面名称
     */
    private String pageName;

    /**
     * 页面类型 {@link PageTypeEnum#value}
     */
    private Integer pageType;

    /**
     * 页面地址
     */
    private String pageUrl;

    /**
     * 页面效果图地址
     */
    private String pageImg;

    /**
     * 页面状态 {@link PageStatusEnum#value}
     */
    private Integer pageStatus;

    /**
     * 页面md5
     */
    private String pageMd5;

    /**
     * 页面其他信息
     */
    private String pageInfo;

    /**
     * 页面最后操作人
     */
    private String operatorName;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /**
     * 落地页链接 eg:https://m.7hotest.com/item/detail2?id=832&pid=168
     */
    private String landPageUrl;

    /**
     * 创建人
     */
    private String createName;

    /**
     * 页面原生类型
     */
    private Integer originType;

    /**
     * 标签
     */
    private String tagNums;

    /**
     * 页面表单策略
     */
    private List<PageFormStrategyDto> strategyTypeList;

    /**
     * 自动打标
     */
    private String autoPromoteTag;

    /**
     * 是否是保存落地页
     */
    private Boolean landPageSaveFlag;

    /**
     * 媒体备案信息自定义
     */
    private String landpageMedia;

    private Long merchantId;

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getLandpageMedia() {
        return landpageMedia;
    }

    public void setLandpageMedia(String landpageMedia) {
        this.landpageMedia = landpageMedia;
    }

    public Boolean getLandPageSaveFlag() {
        return landPageSaveFlag;
    }

    public void setLandPageSaveFlag(Boolean landPageSaveFlag) {
        this.landPageSaveFlag = landPageSaveFlag;
    }

    public String getAutoPromoteTag() {
        return autoPromoteTag;
    }

    public void setAutoPromoteTag(String autoPromoteTag) {
        this.autoPromoteTag = autoPromoteTag;
    }

    public String getTagNums() {
        return tagNums;
    }

    public void setTagNums(String tagNums) {
        this.tagNums = tagNums;
    }
    /**
     * 代码配置 目前只有通过代码添加模版的场景下才会传值
     */
    private String codeConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPageName() {
        return pageName;
    }

    public void setPageName(String pageName) {
        this.pageName = pageName;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public Integer getPageStatus() {
        return pageStatus;
    }

    public void setPageStatus(Integer pageStatus) {
        this.pageStatus = pageStatus;
    }

    public String getPageMd5() {
        return pageMd5;
    }

    public void setPageMd5(String pageMd5) {
        this.pageMd5 = pageMd5;
    }

    public String getPageInfo() {
        return pageInfo;
    }

    public void setPageInfo(String pageInfo) {
        this.pageInfo = pageInfo;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getPageImg() {
        return pageImg;
    }

    public void setPageImg(String pageImg) {
        this.pageImg = pageImg;
    }

    public String getLandPageUrl() {
        return landPageUrl;
    }

    public void setLandPageUrl(String landPageUrl) {
        this.landPageUrl = landPageUrl;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<PageFormStrategyDto> getStrategyTypeList() {
        return strategyTypeList;
    }

    public void setStrategyTypeList(List<PageFormStrategyDto> strategyTypeList) {
        this.strategyTypeList = strategyTypeList;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }

    public String getCodeConfig() {
        return codeConfig;
    }

    public void setCodeConfig(String codeConfig) {
        this.codeConfig = codeConfig;
    }
}
